@@ -122,7 +122,7 @@ class Prosody:
     """
 
     def __init__(self):
-        self.pitch_method="praat"
+        self.pitch_method="rapt"
         self.size_frame=0.02
         self.step=0.01
         self.thr_len=0.14
